searchData={"items":[{"type":"module","title":"NxAudio","doc":"# NxAudio\n\nNxAudio is an Elixir library for working with audio tensors, providing functionality similar to Python's torchaudio\nbut built for the Nx ecosystem.","ref":"NxAudio.html"},{"type":"module","title":"Features - NxAudio","doc":"* Audio I/O operations with support for multiple formats\n* Audio transformations and processing\n  * Amplitude to DB\n  * MEL Spectrogram and STFT\n* Spectrogram visualizations\n* Multiple codec support including:\n  * PCM formats (S16, S24, S32, S8, U8, F32, F64)\n  * FLAC\n  * MP3\n  * Vorbis\n  * Opus\n  * AMR (NB/WB)\n  * μ-law and A-law\n  * HTK","ref":"NxAudio.html#module-features"},{"type":"module","title":"Installation - NxAudio","doc":"Add `nx_audio` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nx_audio, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"NxAudio.html#module-installation"},{"type":"module","title":"Dependencies - NxAudio","doc":"NxAudio requires:\n* Elixir ~> 1.17\n* FFmpeg for audio processing capabilities\n* Nx for tensor operations","ref":"NxAudio.html#module-dependencies"},{"type":"module","title":"Usage Examples - NxAudio","doc":"Basic audio operations:\n\n```elixir\n# Reading an audio file\n{:ok, {tensor, sample_rate}} = NxAudio.IO.load(\"path/to/audio.mp3\")\n\n# Generating spectrograms\nspectrogram = NxAudio.Transforms.Spectrogram.transform(tensor, sample_rate: sample_rate)\n```","ref":"NxAudio.html#module-usage-examples"},{"type":"module","title":"Documentation - NxAudio","doc":"Detailed documentation is organized into the following sections:\n* IO - Audio file reading/writing operations\n* Transformations - Audio signal processing functions\n* Visualizations - Spectrogram and waveform visualization tools\n* Codecs - Supported audio format encodings\n\nFor more examples and detailed API documentation, visit the [official documentation](https://hexdocs.pm/nx_audio).","ref":"NxAudio.html#module-documentation"},{"type":"module","title":"License - NxAudio","doc":"This project is licensed under the MIT License.","ref":"NxAudio.html#module-license"},{"type":"module","title":"NxAudio.IO.Encoding","doc":"Represents the supported audio encodings","ref":"NxAudio.IO.Encoding.html"},{"type":"function","title":"NxAudio.IO.Encoding.codec_name_to_encoding/1","doc":"Converts a codec name to an encoding","ref":"NxAudio.IO.Encoding.html#codec_name_to_encoding/1"},{"type":"macro","title":"NxAudio.IO.Encoding.is_pcm?/1","doc":"Checks if the encoding is PCM","ref":"NxAudio.IO.Encoding.html#is_pcm?/1"},{"type":"module","title":"NxAudio.IO.Encoding.Type.ALAW","doc":"","ref":"NxAudio.IO.Encoding.Type.ALAW.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.ALAW.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ALAW.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.ALAW.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ALAW.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.ALAW.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ALAW.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.ALAW.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ALAW.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.ALAW.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ALAW.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.AMR_NB","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_NB.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.AMR_NB.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_NB.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.AMR_NB.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_NB.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.AMR_NB.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_NB.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.AMR_NB.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_NB.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.AMR_NB.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_NB.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.AMR_WB","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_WB.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.AMR_WB.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_WB.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.AMR_WB.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_WB.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.AMR_WB.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_WB.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.AMR_WB.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_WB.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.AMR_WB.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.AMR_WB.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.FLAC","doc":"","ref":"NxAudio.IO.Encoding.Type.FLAC.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.FLAC.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.FLAC.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.FLAC.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.FLAC.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.FLAC.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.FLAC.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.FLAC.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.FLAC.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.FLAC.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.FLAC.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.HTK","doc":"","ref":"NxAudio.IO.Encoding.Type.HTK.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.HTK.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.HTK.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.HTK.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.HTK.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.HTK.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.HTK.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.HTK.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.HTK.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.HTK.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.HTK.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.MP3","doc":"","ref":"NxAudio.IO.Encoding.Type.MP3.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.MP3.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.MP3.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.MP3.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.MP3.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.MP3.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.MP3.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.MP3.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.MP3.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.MP3.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.MP3.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.OPUS","doc":"","ref":"NxAudio.IO.Encoding.Type.OPUS.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.OPUS.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.OPUS.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.OPUS.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.OPUS.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.OPUS.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.OPUS.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.OPUS.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.OPUS.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.OPUS.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.OPUS.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.PCM_F32","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F32.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_F32.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F32.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_F32.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F32.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_F32.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F32.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_F32.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F32.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.PCM_F32.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F32.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.PCM_F64","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F64.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_F64.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F64.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_F64.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F64.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_F64.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F64.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_F64.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F64.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.PCM_F64.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_F64.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.PCM_S16","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S16.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S16.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S16.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S16.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S16.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S16.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S16.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S16.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S16.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.PCM_S16.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S16.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.PCM_S24","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S24.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S24.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S24.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S24.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S24.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S24.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S24.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S24.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S24.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.PCM_S24.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S24.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.PCM_S32","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S32.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S32.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S32.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S32.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S32.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S32.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S32.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S32.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S32.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.PCM_S32.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S32.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.PCM_S8","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S8.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S8.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S8.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S8.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S8.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S8.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S8.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_S8.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S8.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.PCM_S8.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_S8.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.PCM_U8","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_U8.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_U8.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_U8.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_U8.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_U8.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_U8.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_U8.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.PCM_U8.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_U8.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.PCM_U8.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.PCM_U8.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.ULAW","doc":"","ref":"NxAudio.IO.Encoding.Type.ULAW.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.ULAW.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ULAW.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.ULAW.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ULAW.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.ULAW.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ULAW.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.ULAW.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ULAW.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.ULAW.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.ULAW.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.UNKNOWN","doc":"","ref":"NxAudio.IO.Encoding.Type.UNKNOWN.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.UNKNOWN.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.UNKNOWN.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.UNKNOWN.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.UNKNOWN.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.UNKNOWN.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.UNKNOWN.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.UNKNOWN.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.UNKNOWN.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.UNKNOWN.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.UNKNOWN.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type.VORBIS","doc":"","ref":"NxAudio.IO.Encoding.Type.VORBIS.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.VORBIS.codec_names/0","doc":"","ref":"NxAudio.IO.Encoding.Type.VORBIS.html#codec_names/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.VORBIS.downcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.VORBIS.html#downcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.VORBIS.upcase_value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.VORBIS.html#upcase_value/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.VORBIS.value/0","doc":"","ref":"NxAudio.IO.Encoding.Type.VORBIS.html#value/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.VORBIS.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.VORBIS.html#t:t/0"},{"type":"exception","title":"NxAudio.Commons.Errors.Framework","doc":"Errors related to the NxAudio framework itself.","ref":"NxAudio.Commons.Errors.Framework.html"},{"type":"function","title":"NxAudio.Commons.Errors.Framework.exception/0","doc":"","ref":"NxAudio.Commons.Errors.Framework.html#exception/0"},{"type":"function","title":"NxAudio.Commons.Errors.Framework.message/1","doc":"","ref":"NxAudio.Commons.Errors.Framework.html#message/1"},{"type":"exception","title":"NxAudio.Commons.Errors.IO","doc":"Errors related to input/output operations.","ref":"NxAudio.Commons.Errors.IO.html"},{"type":"function","title":"NxAudio.Commons.Errors.IO.exception/0","doc":"","ref":"NxAudio.Commons.Errors.IO.html#exception/0"},{"type":"function","title":"NxAudio.Commons.Errors.IO.message/1","doc":"","ref":"NxAudio.Commons.Errors.IO.html#message/1"},{"type":"exception","title":"NxAudio.Commons.Errors.Invalid","doc":"Errors related to invalid data or inputs.","ref":"NxAudio.Commons.Errors.Invalid.html"},{"type":"function","title":"NxAudio.Commons.Errors.Invalid.exception/0","doc":"","ref":"NxAudio.Commons.Errors.Invalid.html#exception/0"},{"type":"function","title":"NxAudio.Commons.Errors.Invalid.message/1","doc":"","ref":"NxAudio.Commons.Errors.Invalid.html#message/1"},{"type":"exception","title":"NxAudio.Commons.Errors.Unknown","doc":"Errors that are unknown or unclassified","ref":"NxAudio.Commons.Errors.Unknown.html"},{"type":"function","title":"NxAudio.Commons.Errors.Unknown.exception/0","doc":"","ref":"NxAudio.Commons.Errors.Unknown.html#exception/0"},{"type":"function","title":"NxAudio.Commons.Errors.Unknown.message/1","doc":"","ref":"NxAudio.Commons.Errors.Unknown.html#message/1"},{"type":"module","title":"NxAudio.Commons.Windows","doc":"NX Implementation of common window functions.","ref":"NxAudio.Commons.Windows.html"},{"type":"function","title":"NxAudio.Commons.Windows.haan/1","doc":"Creates a Hann window of size `window_length`.  \n\nArgs:\n  window_length: Length of the window. Must be positive integer.  \n  periodic: If true, returns a periodic window for use with FFT. Defaults to true.  \n\nReturns:\n  A 1-D tensor of size (window_length,) containing the window","ref":"NxAudio.Commons.Windows.html#haan/1"},{"type":"function","title":"Examples - NxAudio.Commons.Windows.haan/1","doc":"iex> Hann.create(window_length: 4)\n    #Nx.Tensor\n      f32[4]\n      [0.0, 0.5, 0.5, 0.0]\n    >","ref":"NxAudio.Commons.Windows.html#haan/1-examples"},{"type":"behaviour","title":"NxAudio.IO","doc":"Defines a behaviour for audio backend operations","ref":"NxAudio.IO.html"},{"type":"callback","title":"NxAudio.IO.info/1","doc":"Returns the audio metadata for a given file.","ref":"NxAudio.IO.html#c:info/1"},{"type":"callback","title":"NxAudio.IO.load/2","doc":"Loads an audio file from a given URI and returns a tuple with the audio tensor and the sample rate.","ref":"NxAudio.IO.html#c:load/2"},{"type":"callback","title":"NxAudio.IO.save/3","doc":"Saves an audio tensor to a given URI.","ref":"NxAudio.IO.html#c:save/3"},{"type":"type","title":"NxAudio.IO.audio_tensor/0","doc":"A 2D tensor representing audio data. By default,\nthe first dimension is the amount of channels and the second dimension is the amount of samples.","ref":"NxAudio.IO.html#t:audio_tensor/0"},{"type":"type","title":"NxAudio.IO.file_uri/0","doc":"Defines the input for the load function, which can be a binary audio or a valid file path","ref":"NxAudio.IO.html#t:file_uri/0"},{"type":"type","title":"NxAudio.IO.io_errors/0","doc":"Defines the possible errors that can occur when loading an audio file","ref":"NxAudio.IO.html#t:io_errors/0"},{"type":"type","title":"NxAudio.IO.sample_rate/0","doc":"Audio sample rate in Hz","ref":"NxAudio.IO.html#t:sample_rate/0"},{"type":"module","title":"NxAudio.IO.AudioMetadata","doc":"Represents the metadata of an audio file","ref":"NxAudio.IO.AudioMetadata.html"},{"type":"type","title":"NxAudio.IO.AudioMetadata.t/0","doc":"sample_rate: The sample rate of the audio file in Hz e.g. 44100\nnum_frames: The number of frames in the audio file e.g. 1000\nnum_channels: The number of channels in the audio file e.g. 2\nbits_per_sample: The number of bits per sample in the audio file e.g. 16\nencoding: The encoding of the audio file e.g. NxAudio.IO.Encoding.Type.PCM_S","ref":"NxAudio.IO.AudioMetadata.html#t:t/0"},{"type":"module","title":"NxAudio.IO.BackendReadConfig","doc":"Defines how the backend should read the audio file.","ref":"NxAudio.IO.BackendReadConfig.html"},{"type":"function","title":"NxAudio.IO.BackendReadConfig.validate/1","doc":"Parses and validate a keyword list into a valid audio backend config","ref":"NxAudio.IO.BackendReadConfig.html#validate/1"},{"type":"type","title":"NxAudio.IO.BackendReadConfig.t/0","doc":"* `:frame_offset` (`t:non_neg_integer/0`) - Number of frames to skip before start reading data The default value is `0`.\n\n* `:num_frames` (`t:integer/0`) - Maximum number of frames to read. -1 reads all the remaining samples, starting from frame_offset. \n  This function may return the less number of frames if there is not enough frames in the given file The default value is `-1`.\n\n* `:normalize` (`t:boolean/0`) - When true, this function converts the native sample type to float32. Default: true.\n\n  If input file is integer WAV, giving False will change the resulting Tensor type to integer type. This argument has no effect for formats other than integer WAV type.\n\n  The default value is `true`.\n\n* `:channels_first` (`t:boolean/0`) - When True, the returned Tensor has dimension [channel, time]. Otherwise, the returned Tensor’s dimension is [time, channel]. The default value is `true`.\n\n* `:buffer_size` (`t:integer/0`) - Size of buffer to use when processing file-like objects, in bytes. The default value is `4096`.\n\n* `:backend` - Backend to use for reading audio files The default value is `:ffmpeg`.","ref":"NxAudio.IO.BackendReadConfig.html#t:t/0"},{"type":"module","title":"NxAudio.IO.BackendSaveConfig","doc":"Defines how the backend should save the audio tensor.","ref":"NxAudio.IO.BackendSaveConfig.html"},{"type":"function","title":"NxAudio.IO.BackendSaveConfig.validate/1","doc":"Parses and validate a keyword list into a valid audio backend config","ref":"NxAudio.IO.BackendSaveConfig.html#validate/1"},{"type":"type","title":"NxAudio.IO.BackendSaveConfig.t/0","doc":"* `:sample_rate` (`t:non_neg_integer/0`) - Required. Which sampling rate to use when writing the file\n\n* `:channels_first` (`t:boolean/0`) - If true, the given tensor is interpreted as [channel, time], otherwise [time, channel] The default value is `true`.\n\n* `:format` - Override the audio format. When uri argument is path-like object, audio format is inferred from file extension. \n  If the file extension is missing or different, you can specify the correct format with this argument.\n  When uri argument is file-like object, this argument is required.\n\n* `:encoding` - Changes the encoding for supported formats. This argument is effective only for supported formats, i.e. \"wav\" and \"flac\"\n\n* `:buffer_size` (`t:integer/0`) - Size of buffer to use when processing file-like objects, in bytes. The default value is `4096`.\n\n* `:backend` - Backend to use for reading audio files The default value is `:ffmpeg`.","ref":"NxAudio.IO.BackendSaveConfig.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Backends.FFmpeg","doc":"Implements a FFMPEG backend to deal with audio files.\nThis module requires FFMPEG to be installed on the system.","ref":"NxAudio.IO.Backends.FFmpeg.html"},{"type":"module","title":"NxAudio.IO.Backends.FFmpegReader","doc":"Reading operations using the FFmpeg backend","ref":"NxAudio.IO.Backends.FFmpegReader.html"},{"type":"module","title":"NxAudio.IO.Backends.FFmpegWriter","doc":"Writing operations using the FFmpeg backend","ref":"NxAudio.IO.Backends.FFmpegWriter.html"},{"type":"exception","title":"NxAudio.IO.Errors.FailedToBufferFile","doc":"Error when writing the tensor to a temporary file","ref":"NxAudio.IO.Errors.FailedToBufferFile.html"},{"type":"function","title":"NxAudio.IO.Errors.FailedToBufferFile.exception/0","doc":"","ref":"NxAudio.IO.Errors.FailedToBufferFile.html#exception/0"},{"type":"type","title":"NxAudio.IO.Errors.FailedToBufferFile.t/0","doc":"","ref":"NxAudio.IO.Errors.FailedToBufferFile.html#t:t/0"},{"type":"exception","title":"NxAudio.IO.Errors.FailedToExecuteBackend","doc":"Error raised when an audio file cannot be parsed using a backend tooling.","ref":"NxAudio.IO.Errors.FailedToExecuteBackend.html"},{"type":"function","title":"NxAudio.IO.Errors.FailedToExecuteBackend.exception/0","doc":"","ref":"NxAudio.IO.Errors.FailedToExecuteBackend.html#exception/0"},{"type":"type","title":"NxAudio.IO.Errors.FailedToExecuteBackend.t/0","doc":"","ref":"NxAudio.IO.Errors.FailedToExecuteBackend.html#t:t/0"},{"type":"exception","title":"NxAudio.IO.Errors.InvalidBackendConfigurations","doc":"Error when a invalid configuration is provided to a backend tool.","ref":"NxAudio.IO.Errors.InvalidBackendConfigurations.html"},{"type":"function","title":"NxAudio.IO.Errors.InvalidBackendConfigurations.exception/0","doc":"","ref":"NxAudio.IO.Errors.InvalidBackendConfigurations.html#exception/0"},{"type":"type","title":"NxAudio.IO.Errors.InvalidBackendConfigurations.t/0","doc":"","ref":"NxAudio.IO.Errors.InvalidBackendConfigurations.html#t:t/0"},{"type":"exception","title":"NxAudio.IO.Errors.InvalidMetadata","doc":"Error when an invalid metadata is returned by a backend tool.","ref":"NxAudio.IO.Errors.InvalidMetadata.html"},{"type":"function","title":"NxAudio.IO.Errors.InvalidMetadata.exception/0","doc":"","ref":"NxAudio.IO.Errors.InvalidMetadata.html#exception/0"},{"type":"type","title":"NxAudio.IO.Errors.InvalidMetadata.t/0","doc":"","ref":"NxAudio.IO.Errors.InvalidMetadata.html#t:t/0"},{"type":"module","title":"NxAudio.Transforms.AmplitudeToDb","doc":"Represents the amplitude to decibel transformation for audio signals.","ref":"NxAudio.Transforms.AmplitudeToDb.html"},{"type":"function","title":"NxAudio.Transforms.AmplitudeToDb.transform/2","doc":"Returns the decibel representation of a power or magnitude spectrogram.","ref":"NxAudio.Transforms.AmplitudeToDb.html#transform/2"},{"type":"module","title":"NxAudio.Transforms.MelSpectrogram","doc":"Implements Mel-scaled spectrograms - a perceptually-motivated time-frequency representation of audio.\n\nThe mel spectrogram applies mel filterbanks to a regular spectrogram, mapping linear frequency bins to the mel scale that better approximates human auditory perception.","ref":"NxAudio.Transforms.MelSpectrogram.html"},{"type":"module","title":"Mel Scale - NxAudio.Transforms.MelSpectrogram","doc":"The mel scale relates perceived frequency to actual frequency in Hz. Two main formulas are supported:\n\nHTK (default):\n$$m = 2595 \\log_{10}(1 + \\frac{f}{700}) $$\n\nSlaney:\n$$ m = \\begin{cases} \nf/f_{min} \\cdot m_{min} & f < f_{min} \\\nm_{min} + \\log(f/f_{min})/\\text{step} & f \\geq f_{min}\n\\end{cases} $$\n\nwhere $f_{min}=1000$, $m_{min}=25$, $\\text{step}=\\log(6.4)/27$","ref":"NxAudio.Transforms.MelSpectrogram.html#module-mel-scale"},{"type":"module","title":"Filterbank Construction - NxAudio.Transforms.MelSpectrogram","doc":"Mel filterbanks are triangular overlapping windows spaced uniformly on the mel scale:\n\n1. Convert frequencies to mel scale\n2. Create `n_mels + 2` points evenly spaced in mel scale\n3. Convert back to Hz to get filterbank center frequencies\n4. Create triangular filters:\n\n$$ H_m(k) = \\begin{cases}\n0 & k < f(m-1) \\\n\\frac{k - f(m-1)}{f(m) - f(m-1)} & f(m-1) \\leq k < f(m) \\\n\\frac{f(m+1) - k}{f(m+1) - f(m)} & f(m) \\leq k < f(m+1) \\\n0 & k \\geq f(m+1)\n\\end{cases} $$\n\nwhere $f(m)$ is the frequency of filterbank $m$.","ref":"NxAudio.Transforms.MelSpectrogram.html#module-filterbank-construction"},{"type":"module","title":"Applications - NxAudio.Transforms.MelSpectrogram","doc":"Mel spectrograms are widely used in:\n- Speech recognition\n- Music information retrieval  \n- Audio classification\n- Sound event detection\n- Speaker identification\n\nBy mapping frequencies to a perceptual scale and reducing dimensionality, mel spectrograms provide an efficient and meaningful audio representation.","ref":"NxAudio.Transforms.MelSpectrogram.html#module-applications"},{"type":"function","title":"NxAudio.Transforms.MelSpectrogram.transform/2","doc":"Computes the mel-scaled spectrogram of an audio signal.\n\nArgs:\n  audio_tensor: Input audio tensor of shape [samples] or [channels, samples]\n  config: MelSpectrogram configuration options `NxAudio.Transforms.MelSpectrogramConfig`\n\nReturns:\n  If input is [samples]: Returns tensor of shape [time, n_mels]\n  If input is [channels, samples]: Returns tensor of shape [channels, time, n_mels]","ref":"NxAudio.Transforms.MelSpectrogram.html#transform/2"},{"type":"module","title":"NxAudio.Transforms.MelSpectrogramConfig","doc":"Configuration options for mel spectrogram transformation.","ref":"NxAudio.Transforms.MelSpectrogramConfig.html"},{"type":"function","title":"NxAudio.Transforms.MelSpectrogramConfig.validate/1","doc":"Parses and validate a keyword list into a valid mel spectrogram config","ref":"NxAudio.Transforms.MelSpectrogramConfig.html#validate/1"},{"type":"type","title":"NxAudio.Transforms.MelSpectrogramConfig.t/0","doc":"* `:sample_rate` (`t:non_neg_integer/0`) - Sample rate of audio signal. The default value is `16000`.\n\n* `:n_fft` (`t:non_neg_integer/0`) - Size of FFT, creates n_fft // 2 + 1 bins. The default value is `400`.\n\n* `:win_length` (`t:non_neg_integer/0`) - Number of samples in each frame. By default its n_fft.\n\n* `:hop_length` (`t:non_neg_integer/0`) - Number of samples between successive frames. By default its win_length/2.\n\n* `:f_min` (`t:float/0`) - Minimum frequency. The default value is `0.0`.\n\n* `:f_max` (`t:float/0`) - Maximum frequency. The default value is `nil`.\n\n* `:pad` (`t:non_neg_integer/0`) - Two sided padding of signal. The default value is `0`.\n\n* `:n_mels` (`t:non_neg_integer/0`) - Number of mel filterbanks. The default value is `128`.\n\n* `:window_fn` (`t:term/0`) - Window function to apply to each frame. The default value is `&NxAudio.Commons.Windows.haan/1`.\n\n* `:power` (`t:float/0`) - Exponent for the magnitude spectrogram, (must be > 0) e.g., 1 for magnitude, 2 for power, etc. If None, then the complex spectrum is returned instead. The default value is `2`.\n\n* `:normalized` - Whether to normalize by magnitude after stft. choices are \"window\" and \"frame_length\", if specific normalization type is desirable.\n\n* `:wkwargs` (`t:keyword/0`) - Arguments for window function. The default value is `[]`.\n\n* `:center` (`t:boolean/0`) - Whether to pad waveform on both sides so that the t-th frame is centered at time t * hop_length. The default value is `true`.\n\n* `:pad_mode` (`t:atom/0`) - Controls the padding method used when center is true. The default value is `:reflect`.\n\n* `:onesided` (`t:boolean/0`) - Controls whether to return half of results to avoid redundancy. The default value is `true`.\n\n* `:norm` - If “slaney”, divide the triangular mel weights by the width of the mel band (area normalization).\n\n* `:mel_scale` - Scale to use The default value is `:htk`.","ref":"NxAudio.Transforms.MelSpectrogramConfig.html#t:t/0"},{"type":"module","title":"NxAudio.Transforms.Spectrogram","doc":"Spectrogram transformation for audio tensors.","ref":"NxAudio.Transforms.Spectrogram.html"},{"type":"function","title":"NxAudio.Transforms.Spectrogram.transform/2","doc":"Computes the spectrogram of an audio signal.  \n\nArgs:  \n  audio_tensor: Input audio tensor of shape [samples] or [channels, samples]  \n  config: Spectrogram configuration options `NxAudio.Transforms.SpectrogramConfig`  \n\nReturns:  \n  If input is [samples]: Returns tensor of shape [time, frequency]  \n  If input is [channels, samples]: Returns tensor of shape [channels, time, frequency]  \n\nNote:\n  Expected input format is {channels, time} for multi-channel audio","ref":"NxAudio.Transforms.Spectrogram.html#transform/2"},{"type":"module","title":"NxAudio.Transforms.SpectrogramConfig","doc":"Configuration options for spectrogram transformation.","ref":"NxAudio.Transforms.SpectrogramConfig.html"},{"type":"function","title":"NxAudio.Transforms.SpectrogramConfig.maybe_calculate_hop_length/2","doc":"","ref":"NxAudio.Transforms.SpectrogramConfig.html#maybe_calculate_hop_length/2"},{"type":"function","title":"NxAudio.Transforms.SpectrogramConfig.maybe_calculate_win_length/2","doc":"","ref":"NxAudio.Transforms.SpectrogramConfig.html#maybe_calculate_win_length/2"},{"type":"function","title":"NxAudio.Transforms.SpectrogramConfig.validate/1","doc":"Parses and validate a keyword list into a valid spectrogram config","ref":"NxAudio.Transforms.SpectrogramConfig.html#validate/1"},{"type":"type","title":"NxAudio.Transforms.SpectrogramConfig.t/0","doc":"* `:n_fft` (`t:non_neg_integer/0`) - Size of FFT, creates n_fft // 2 + 1 bins. The default value is `400`.\n\n* `:win_length` (`t:non_neg_integer/0`) - Number of samples in each frame. By default its half of the n_fft\n\n* `:hop_length` (`t:non_neg_integer/0`) - Number of samples between successive frames., By default its half of the n_fft\n\n* `:pad` (`t:non_neg_integer/0`) - Two sided padding of signal. The default value is `0`.\n\n* `:window_fn` (`t:term/0`) - Window function to apply to each frame. The default value is `&NxAudio.Commons.Windows.haan/1`.\n\n* `:power` (`t:float/0`) - Exponent for the magnitude spectrogram, (must be > 0) e.g., 1 for magnitude, 2 for power, etc. If None, then the complex spectrum is returned instead. The default value is `2`.\n\n* `:normalized` - Whether to normalize by magnitude after stft. choices are \"window\" and \"frame_length\", if specific normalization type is desirable.\n\n* `:wkwargs` (`t:keyword/0`) - Arguments for window function. The default value is `[]`.\n\n* `:center` (`t:boolean/0`) - Whether to pad waveform on both sides so that the t-th frame is centered at time t * hop_length. The default value is `true`.\n\n* `:pad_mode` (`t:atom/0`) - Controls the padding method used when center is true. The default value is `:reflect`.\n\n* `:onesided` (`t:boolean/0`) - Controls whether to return half of results to avoid redundancy. The default value is `true`.","ref":"NxAudio.Transforms.SpectrogramConfig.html#t:t/0"},{"type":"exception","title":"NxAudio.Transforms.Errors.InvalidTransformationConfiguration","doc":"Error when a invalid configuration is provided to a transformation.","ref":"NxAudio.Transforms.Errors.InvalidTransformationConfiguration.html"},{"type":"function","title":"NxAudio.Transforms.Errors.InvalidTransformationConfiguration.exception/0","doc":"","ref":"NxAudio.Transforms.Errors.InvalidTransformationConfiguration.html#exception/0"},{"type":"type","title":"NxAudio.Transforms.Errors.InvalidTransformationConfiguration.t/0","doc":"","ref":"NxAudio.Transforms.Errors.InvalidTransformationConfiguration.html#t:t/0"},{"type":"module","title":"NxAudio.Visualizations.Spectrogram","doc":"Provides a binned heatmap visualization for Nx-based Spectrograms.\n\nEach Spectrogram index `[t, m or f]` or `[c, t, m or f]` is treated as numeric data:\n  - \"x_idx\" = t\n  - \"y_idx\" = m (representing MEL frequency bands) or f (representing linear frequency bands)\n\nNote: This module requires the `vega_lite` package to be installed.\nAdd `{:vega_lite, \"~> 0.1\"}` to your dependencies.","ref":"NxAudio.Visualizations.Spectrogram.html"},{"type":"function","title":"NxAudio.Visualizations.Spectrogram.plot!/2","doc":"Plots a **binned** Spectrogram heatmap. The tensor can be:\n  - `[time, mel/frequency]`\n  - `[channels, time, mel/frequency]`","ref":"NxAudio.Visualizations.Spectrogram.html#plot!/2"},{"type":"function","title":"Example - NxAudio.Visualizations.Spectrogram.plot!/2","doc":"spectrogram_tensor =\n      NxAudio.Transforms.MelSpectrogram.transform(\n        audio_tensor,\n        sample_rate: 16000,\n        n_fft: 512,\n        n_mels: 80\n      )\n\n    NxAudio.Visualizations.Spectrogram.plot!(\n      spectrogram_tensor,\n      title: \"My MEL Spectrogram\",\n      color_domain: [0, 300],\n      bin_maxbins: 50,\n      bin_maxbins: 40\n    )","ref":"NxAudio.Visualizations.Spectrogram.html#plot!/2-example"},{"type":"module","title":"NxAudio.Visualizations.SpectrogramConfig","doc":"Defines the configuration schema for the Spectrogram visualization.","ref":"NxAudio.Visualizations.SpectrogramConfig.html"},{"type":"function","title":"NxAudio.Visualizations.SpectrogramConfig.validate!/1","doc":"Validates the given configuration options and returns the parsed configuration.","ref":"NxAudio.Visualizations.SpectrogramConfig.html#validate!/1"},{"type":"type","title":"NxAudio.Visualizations.SpectrogramConfig.t/0","doc":"* `:title` (`t:String.t/0`) - Title of the plot. The default value is `\"Spectrogram\"`.\n\n* `:scale_type` - Scale for the color encoding. The default value is `:linear`.\n\n* `:color_domain` (`t:term/0`) - `[min, max]` for the color scale (e.g. `[0, 500]`)\n\n* `:color_scheme` - Color scheme for the plot. The default value is `:viridis`.\n\n* `:bin_maxbins` (`t:non_neg_integer/0`) - Approx. max bins for the time and frequency dimensions. The default value is `60`.\n\n* `:x_axis_label` (`t:String.t/0`) - Label for the x-axis. The default value is `\"Time Index\"`.\n\n* `:y_axis_label` (`t:String.t/0`) - Label for the y-axis. The default value is `\"Frequency Index\"`.\n\n* `:width` (`t:non_neg_integer/0`) - Chart width in pixels. The default value is `800`.\n\n* `:height` (`t:non_neg_integer/0`) - Chart height in pixels. The default value is `600`.","ref":"NxAudio.Visualizations.SpectrogramConfig.html#t:t/0"},{"type":"module","title":"NxAudio.IO.Encoding.Type","doc":"Codec Names","ref":"NxAudio.IO.Encoding.Type.html"},{"type":"function","title":"NxAudio.IO.Encoding.Type.default/0","doc":"","ref":"NxAudio.IO.Encoding.Type.html#default/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.enums/0","doc":"","ref":"NxAudio.IO.Encoding.Type.html#enums/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.from/1","doc":"","ref":"NxAudio.IO.Encoding.Type.html#from/1"},{"type":"function","title":"NxAudio.IO.Encoding.Type.options/0","doc":"","ref":"NxAudio.IO.Encoding.Type.html#options/0"},{"type":"function","title":"NxAudio.IO.Encoding.Type.value/1","doc":"","ref":"NxAudio.IO.Encoding.Type.html#value/1"},{"type":"function","title":"NxAudio.IO.Encoding.Type.values/0","doc":"","ref":"NxAudio.IO.Encoding.Type.html#values/0"},{"type":"type","title":"NxAudio.IO.Encoding.Type.t/0","doc":"","ref":"NxAudio.IO.Encoding.Type.html#t:t/0"},{"type":"exception","title":"NxAudio.Commons.Errors.Unknown.UnknownError","doc":"Default unexpected error","ref":"NxAudio.Commons.Errors.Unknown.UnknownError.html"},{"type":"function","title":"NxAudio.Commons.Errors.Unknown.UnknownError.exception/0","doc":"","ref":"NxAudio.Commons.Errors.Unknown.UnknownError.html#exception/0"},{"type":"exception","title":"NxAudio.Visualizations.Errors.InvalidVisualizationConfig","doc":"Error when a invalid configuration is provided to a visualization.","ref":"NxAudio.Visualizations.Errors.InvalidVisualizationConfig.html"},{"type":"function","title":"NxAudio.Visualizations.Errors.InvalidVisualizationConfig.exception/0","doc":"","ref":"NxAudio.Visualizations.Errors.InvalidVisualizationConfig.html#exception/0"},{"type":"type","title":"NxAudio.Visualizations.Errors.InvalidVisualizationConfig.t/0","doc":"","ref":"NxAudio.Visualizations.Errors.InvalidVisualizationConfig.html#t:t/0"},{"type":"extras","title":"Introduction","doc":"# NxAudio\n\nNxAudio is an Elixir library for working with audio tensors, providing functionality similar to Python's torchaudio\nbut built for the Nx ecosystem.","ref":"readme.html"},{"type":"extras","title":"Features - Introduction","doc":"* Audio I/O operations with support for multiple formats\n* Audio transformations and processing\n  * Amplitude to DB\n  * MEL Spectrogram and STFT\n* Spectrogram visualizations\n* Multiple codec support including:\n  * PCM formats (S16, S24, S32, S8, U8, F32, F64)\n  * FLAC\n  * MP3\n  * Vorbis\n  * Opus\n  * AMR (NB/WB)\n  * μ-law and A-law\n  * HTK","ref":"readme.html#features"},{"type":"extras","title":"Installation - Introduction","doc":"Add `nx_audio` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nx_audio, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Dependencies - Introduction","doc":"NxAudio requires:\n* Elixir ~> 1.17\n* FFmpeg for audio processing capabilities\n* Nx for tensor operations","ref":"readme.html#dependencies"},{"type":"extras","title":"Usage Examples - Introduction","doc":"Basic audio operations:\n\n```elixir\n# Reading an audio file\n{:ok, {tensor, sample_rate}} = NxAudio.IO.load(\"path/to/audio.mp3\")\n\n# Generating spectrograms\nspectrogram = NxAudio.Transforms.Spectrogram.transform(tensor, sample_rate: sample_rate)\n```","ref":"readme.html#usage-examples"},{"type":"extras","title":"Documentation - Introduction","doc":"Detailed documentation is organized into the following sections:\n* IO - Audio file reading/writing operations\n* Transformations - Audio signal processing functions\n* Visualizations - Spectrogram and waveform visualization tools\n* Codecs - Supported audio format encodings\n\nFor more examples and detailed API documentation, visit the [official documentation](https://hexdocs.pm/nx_audio).","ref":"readme.html#documentation"},{"type":"extras","title":"License - Introduction","doc":"This project is licensed under the MIT License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"","ref":"changelog.html"},{"type":"extras","title":"Spectrogram Visualizations","doc":"# NxAudio\n\n```elixir\nMix.install([\n  {:vega_lite, \"~> 0.1.6\"},\n  {:kino_vega_lite, \"~> 0.1.11\"},\n  {:nx_audio, path: \"/Users/ygorcastor/Development/personal/nx_audio\"}\n])\n\nMix.Tasks.Compile.Rambo.run([])\n```","ref":"visualizations.html"},{"type":"extras","title":"Processing an audio file and visualizing its spectrograms - Spectrogram Visualizations","doc":"```elixir\nstar_wars = \"/Users/ygorcastor/Downloads/star_wars.wav\"\n\n{:ok, {audio_tensor, sr}} = NxAudio.IO.load(star_wars, [channels_first: true])\n\nNx.shape(audio_tensor)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{1, 66189}\n```\n\n```elixir\nspectrogram = NxAudio.Transforms.Spectrogram.transform(audio_tensor)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Nx.Tensor \n```\n\n```elixir\nNxAudio.Visualizations.Spectrogram.plot!(spectrogram)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n\n\n```elixir\nmel_spectrogram = NxAudio.Transforms.MelSpectrogram.transform(audio_tensor)\nmel_spectrogram_db = NxAudio.Transforms.AmplitudeToDb.transform(mel_spectrogram)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Nx.Tensor \n```\n\n```elixir\nNxAudio.Visualizations.Spectrogram.plot!(mel_spectrogram_db, width: 1800, height: 800)\n```\n\n<!-- livebook:{\"output\":true} -->","ref":"visualizations.html#processing-an-audio-file-and-visualizing-its-spectrograms"},{"type":"extras","title":"License","doc":"Copyright (c) 2024 Ygor Castor https://ygorcastor.github.io\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}